@@ -18,16 +18,16 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include "vinagre-connection.h"
-#include "vinagre-enums.h"
 #include "vinagre-bookmarks.h"
 #include "vinagre-plugins-engine.h"
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 
 struct _VinagreConnectionPrivate
 {
