@@ -30,7 +30,7 @@
 #include <gnome-keyring.h>
 
 #include "vinagre-ssh.h"
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 #include "pty_open.h"
 
 #define SSH_READ_TIMEOUT 40   /* seconds */
@@ -485,9 +485,9 @@ handle_login (GtkWindow *parent,
 
 	  get_hostname_and_fingerprint_from_line (buffer, &hostname, &fingerprint);
 
-	  message = g_strdup_printf (_("The identity of the remote computer (%s) is unknown.\n"
-				       "This happens when you log in to a computer the first time.\n\n"
-				       "The identity sent by the remote computer is %s. "
+	  message = g_strdup_printf (_("The identity of the remote host (%s) is unknown.\n"
+				       "This happens when you log in to a host the first time.\n\n"
+				       "The identity sent by the remote host is %s. "
 				       "If you want to be absolutely sure it is safe to continue, "
 				       "contact the system administrator."),
 				     hostname ? hostname : host, fingerprint);
@@ -559,7 +559,7 @@ handle_login (GtkWindow *parent,
                 &keyring_item_id);
 
       if (result != GNOME_KEYRING_RESULT_OK)
-        vinagre_utils_show_error (_("Error saving the credentials on the keyring."),
+        vinagre_utils_show_error_dialog (_("Error saving the credentials on the keyring."),
 				  gnome_keyring_result_to_message (result),
 				  parent);
 
