@@ -28,10 +28,9 @@
 
 #include "vinagre-tab.h"
 #include "vinagre-notebook.h"
-#include "vinagre-utils.h"
+#include "vinagre-util.h"
 #include "vinagre-prefs.h"
 #include "view/autoDrawer.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
 
 #define VINAGRE_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), VINAGRE_TYPE_TAB, VinagreTabPrivate))
@@ -48,6 +47,7 @@ struct _VinagreTabPrivate
   VinagreTabState    state;
   GtkWidget         *layout;
   GtkWidget         *toolbar;
+  gboolean          has_screenshot;
 };
 
 G_DEFINE_ABSTRACT_TYPE (VinagreTab, vinagre_tab, GTK_TYPE_VBOX)
@@ -68,7 +68,8 @@ enum
   PROP_0,
   PROP_CONN,
   PROP_WINDOW,
-  PROP_TOOLTIP
+  PROP_TOOLTIP,
+  PROP_HAS_SCREENSHOT
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -139,6 +140,10 @@ vinagre_tab_get_property (GObject    *object,
 	break;
       case PROP_TOOLTIP:
 	g_value_take_string (value, vinagre_tab_get_tooltip (tab));
+	break;
+      case PROP_HAS_SCREENSHOT:
+	g_value_set_boolean (value, tab->priv->has_screenshot);
+	break;
       default:
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	break;			
@@ -166,6 +171,9 @@ vinagre_tab_set_property (GObject      *object,
 			  G_CALLBACK (vinagre_tab_window_state_cb),
 			  tab);
         break;
+      case PROP_HAS_SCREENSHOT:
+	tab->priv->has_screenshot = g_value_get_boolean (value);
+	break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;			
@@ -220,6 +228,29 @@ default_get_extra_title (VinagreTab *tab)
   return NULL;
 }
 
+static GdkPixbuf *
+default_get_screenshot (VinagreTab *tab)
+{
+  cairo_t       *cr;
+  cairo_surface_t *s;
+  GtkAllocation alloc;
+  GdkPixbuf *pix;
+
+  gtk_widget_get_allocation (tab->priv->view, &alloc);
+  s = cairo_image_surface_create (CAIRO_FORMAT_RGB24, alloc.width, alloc.height);
+  cr = cairo_create (s);
+  gtk_widget_draw (tab->priv->view, cr);
+  pix = gdk_pixbuf_get_from_surface (cairo_get_target (cr),
+				     0,
+				     0,
+				     alloc.width,
+				     alloc.height);
+  cairo_destroy (cr);
+  cairo_surface_destroy (s);
+
+  return pix;
+}
+
 static void
 menu_position (GtkMenu    *menu,
 	       gint       *x,
@@ -227,16 +258,14 @@ menu_position (GtkMenu    *menu,
 	       gboolean   *push_in,
 	       VinagreTab *tab)
 {
-  int width, height;
   GdkWindow *window;
 
   window = gtk_widget_get_window (tab->priv->toolbar);
 
   gdk_window_get_origin (window, x, y);
-  gdk_drawable_get_size (window, &width, &height);
 
   *push_in = TRUE;
-  *y += height;
+  *y += gdk_window_get_height (window);
 }
 
 static void
@@ -250,11 +279,11 @@ static void
 active_connections_button_clicked  (GtkToolButton *button,
 				    VinagreTab    *tab)
 {
-  GSList            *connections, *l;
-  VinagrePlugin     *plugin;
-  VinagreConnection *conn;
-  GtkWidget         *menu, *item, *image;
-  gchar             *str, *label;
+  GSList             *connections, *l;
+  VinagreProtocol    *ext;
+  VinagreConnection  *conn;
+  GtkWidget          *menu, *item, *image;
+  gchar              *str, *label;
 
   menu = gtk_menu_new ();
 
@@ -262,10 +291,10 @@ active_connections_button_clicked  (GtkToolButton *button,
   for (l = connections; l; l = l->next)
     {
       conn = VINAGRE_TAB (l->data)->priv->conn;
-      plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-							      vinagre_connection_get_protocol (conn));
+      ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+							   vinagre_connection_get_protocol (conn));
       item = gtk_image_menu_item_new_with_label ("");
-      image = gtk_image_new_from_icon_name (vinagre_plugin_get_icon_name (plugin),
+      image = gtk_image_new_from_icon_name (vinagre_protocol_get_icon_name (ext),
 					    GTK_ICON_SIZE_MENU);
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
@@ -322,7 +351,7 @@ setup_layout (VinagreTab *tab)
 
   /* Close connection */
   button = GTK_WIDGET (gtk_tool_button_new_from_stock (GTK_STOCK_CLOSE));
-  gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (button), _("Close connection"));
+  gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (button), _("Disconnect"));
   gtk_widget_show (GTK_WIDGET (button));
   gtk_toolbar_insert (GTK_TOOLBAR (tab->priv->toolbar), GTK_TOOL_ITEM (button), 0);
   g_signal_connect (button, "clicked", G_CALLBACK (close_button_clicked), tab);
@@ -383,7 +412,7 @@ vinagre_tab_class_init (VinagreTabClass *klass)
   object_class->constructed = vinagre_tab_constructed;
 
   klass->impl_get_tooltip = NULL;
-  klass->impl_get_screenshot = NULL;
+  klass->impl_get_screenshot = default_get_screenshot;
   klass->impl_get_dimensions = default_get_dimensions;
   klass->impl_get_always_sensitive_actions = default_get_always_sensitive_actions;
   klass->impl_get_connected_actions = default_get_connected_actions;
@@ -424,6 +453,17 @@ vinagre_tab_class_init (VinagreTabClass *klass)
 							G_PARAM_STATIC_NICK |
 							G_PARAM_STATIC_BLURB));
 
+  g_object_class_install_property (object_class,
+				   PROP_HAS_SCREENSHOT,
+				   g_param_spec_boolean ("has-screenshot",
+							 "Has Screenshot",
+							 "Whether this tab has the ability to take a screenshot",
+							 FALSE,
+							 G_PARAM_READWRITE |
+							 G_PARAM_STATIC_NAME |
+							 G_PARAM_STATIC_NICK |
+							 G_PARAM_STATIC_BLURB));
+
   signals[TAB_CONNECTED] =
 		g_signal_new ("tab-connected",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -493,7 +533,7 @@ vinagre_tab_add_recent_used (VinagreTab *tab)
   data->is_private = FALSE;
 
   if (!gtk_recent_manager_add_full (manager, uri, data))
-    vinagre_utils_show_error (NULL,
+    vinagre_utils_show_error_dialog (NULL,
 			      _("Error saving recent connection."),
 			      GTK_WINDOW (tab->priv->window));
 
@@ -524,19 +564,17 @@ vinagre_tab_init (VinagreTab *tab)
 GtkWidget *
 vinagre_tab_new (VinagreConnection *conn, VinagreWindow *window)
 {
-  VinagrePlugin *plugin;
-  GtkWidget     *tab;
-  const gchar   *protocol = vinagre_connection_get_protocol (conn);
+  VinagreProtocol *ext;
+  const gchar *protocol = vinagre_connection_get_protocol (conn);
 
-  plugin = g_hash_table_lookup (vinagre_plugin_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ()),
-				protocol);
-  if (!plugin)
+  ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (), protocol);
+  if (!ext)
     {
       g_warning (_("The protocol %s is not supported."), protocol);
       return NULL;
     }
 
-  return vinagre_plugin_new_tab (plugin, conn, window);
+  return vinagre_protocol_new_tab (ext, conn, window);
 }
 
 gchar *
@@ -563,6 +601,12 @@ vinagre_tab_get_dimensions (VinagreTab *tab, int *w, int *h)
   VINAGRE_TAB_GET_CLASS (tab)->impl_get_dimensions (tab, w, h);
 }
 
+/**
+ * vinagre_tab_get_window:
+ * @tab: a Tab
+ *
+ * Return value: (transfer none):
+ */
 VinagreWindow *
 vinagre_tab_get_window (VinagreTab *tab)
 {
@@ -571,6 +615,12 @@ vinagre_tab_get_window (VinagreTab *tab)
   return tab->priv->window;
 }
 
+/**
+ * vinagre_tab_get_conn:
+ * @tab: a Tab
+ *
+ * Return value: (transfer none):
+ */
 VinagreConnection *
 vinagre_tab_get_conn (VinagreTab *tab)
 {
@@ -595,6 +645,12 @@ vinagre_tab_add_view (VinagreTab *tab, GtkWidget *view)
   gtk_widget_modify_bg (viewport, GTK_STATE_NORMAL, &color);
 }
 
+/**
+ * vinagre_tab_get_view:
+ * @tab: a Tab
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_tab_get_view (VinagreTab *tab)
 {
@@ -625,6 +681,12 @@ vinagre_tab_set_notebook (VinagreTab      *tab,
   tab->priv->nb = nb;
 }
 
+/**
+ * vinagre_tab_get_notebook:
+ * @tab: a Tab
+ *
+ * Return value: (transfer none):
+ */
 VinagreNotebook *
 vinagre_tab_get_notebook (VinagreTab *tab)
 {
@@ -647,6 +709,12 @@ vinagre_tab_set_state (VinagreTab *tab, VinagreTabState state)
   tab->priv->state = state;
 }
 
+/**
+ * vinagre_tab_get_toolbar:
+ * @tab: a Tab
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_tab_get_toolbar (VinagreTab *tab)
 {
@@ -655,6 +723,12 @@ vinagre_tab_get_toolbar (VinagreTab *tab)
   return tab->priv->toolbar;
 }
 
+/**
+ * vinagre_tab_get_from_connection:
+ * @conn: a Connection
+ *
+ * Return value: (allow-none) (transfer none):
+ */
 VinagreTab *
 vinagre_tab_get_from_connection (VinagreConnection *conn)
 {
@@ -729,7 +803,7 @@ vinagre_tab_save_credentials_in_keyring (VinagreTab *tab)
                 &tab->priv->keyring_item_id);
 
   if (result != GNOME_KEYRING_RESULT_OK)
-    vinagre_utils_show_error (_("Error saving the credentials on the keyring."),
+    vinagre_utils_show_error_dialog (_("Error saving the credentials on the keyring."),
 			      gnome_keyring_result_to_message (result),
 			      GTK_WINDOW (tab->priv->window));
 
@@ -811,10 +885,13 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
 
   g_return_if_fail (VINAGRE_IS_TAB (tab));
 
+  if (!tab->priv->has_screenshot)
+    return;
+
   pix = VINAGRE_TAB_GET_CLASS (tab)->impl_get_screenshot (tab);
   if (!pix)
     {
-      vinagre_utils_show_error (NULL,
+      vinagre_utils_show_error_dialog (NULL,
 				_("Could not get a screenshot of the connection."),
 				GTK_WINDOW (tab->priv->window));
       return;
@@ -883,7 +960,7 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
 
       if (!gdk_pixbuf_save (pix, filename, name, &error, NULL))
 	{
-	  vinagre_utils_show_error (_("Error saving screenshot"),
+	  vinagre_utils_show_error_dialog (_("Error saving screenshot"),
 				    error->message,
 				    GTK_WINDOW (tab->priv->window));
 	  g_error_free (error);
@@ -939,17 +1016,32 @@ vinagre_tab_free_actions (GSList *actions)
 const gchar *
 vinagre_tab_get_icon_name (VinagreTab *tab)
 {
-  const gchar   *protocol;
-  VinagrePlugin *plugin;
+  const gchar *protocol;
+  VinagreProtocol *ext;
 
   g_return_val_if_fail (VINAGRE_IS_TAB (tab), NULL);
 
   protocol = vinagre_connection_get_protocol (tab->priv->conn);
-  plugin = g_hash_table_lookup (vinagre_plugin_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ()),
-				protocol);
-  g_return_val_if_fail (plugin != NULL, NULL);
+  ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (), protocol);
+  g_return_val_if_fail (ext != NULL, NULL);
 
-  return vinagre_plugin_get_icon_name (plugin);
+  return vinagre_protocol_get_icon_name (ext);
+}
+
+void
+vinagre_tab_set_has_screenshot (VinagreTab *tab, gboolean has_screenshot)
+{
+  g_return_if_fail (VINAGRE_IS_TAB (tab));
+
+  tab->priv->has_screenshot = has_screenshot;
+}
+
+gboolean
+vinagre_tab_get_has_screenshot (VinagreTab *tab)
+{
+  g_return_val_if_fail (VINAGRE_IS_TAB (tab), FALSE);
+
+  return tab->priv->has_screenshot;
 }
 
 /* vim: set ts=8: */
