@@ -21,6 +21,7 @@
  *      Arnaud Maillet <arnaud.maillet@collabora.co.uk>
  */
 
+#include <config.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
@@ -36,8 +37,9 @@
 #include "vinagre-tab.h"
 #include "vinagre-notebook.h"
 #include "vinagre-debug.h"
-#include "vinagre-plugin.h"
+#include "vinagre-protocol.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-util.h"
 
 G_DEFINE_TYPE (VinagreTubeHandler, vinagre_tube_handler, G_TYPE_OBJECT);
 
@@ -221,14 +223,14 @@ vinagre_tube_handler_call_service_cb (TpProxy *channel,
   gchar *port_s;
   gchar *host;
   const gchar *service_s;
-  VinagrePlugin *plugin;
+  VinagreProtocol *plugin;
 
   if (error != NULL)
     {
       error_msg = g_strdup_printf
           (_("Impossible to get service property: %s"),
           error->message);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
+      vinagre_utils_show_error_dialog (NULL, (const gchar *) error_msg,
           GTK_WINDOW (priv->window));
       g_free (priv->hostname);
       g_free (error_msg);
@@ -251,7 +253,7 @@ vinagre_tube_handler_call_service_cb (TpProxy *channel,
     {
       error_msg = g_strdup_printf
           (_("The protocol %s is not supported."), service_s);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
+      vinagre_utils_show_error_dialog (NULL, (const gchar *) error_msg,
           GTK_WINDOW (priv->window));
       g_free (priv->hostname);
       g_free (error_msg);
@@ -265,7 +267,7 @@ vinagre_tube_handler_call_service_cb (TpProxy *channel,
 
   port_s = g_strdup_printf ("%u", priv->port);
 
-  host = g_strconcat (vinagre_plugin_get_protocol (plugin), "://",
+  host = g_strconcat (vinagre_protocol_get_protocol (plugin), "://",
       priv->hostname, ":", port_s,
       NULL);
 
@@ -284,7 +286,7 @@ vinagre_tube_handler_call_service_cb (TpProxy *channel,
     {
       error_msg = g_strdup_printf
           (_("Impossible to create the connection: %s"), error_conn_msg);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
+      vinagre_utils_show_error_dialog (NULL, (const gchar *) error_msg,
           GTK_WINDOW (priv->window));
       g_signal_handler_disconnect (G_OBJECT (priv->channel),
         priv->signal_invalidated_id);
@@ -324,7 +326,7 @@ vinagre_tube_handler_accept_stream_tube_cb (TpChannel *channel,
       error_msg = g_strdup_printf
           (_("Impossible to accept the stream tube: %s"),
           error->message);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
+      vinagre_utils_show_error_dialog (NULL, (const gchar *) error_msg,
           GTK_WINDOW (priv->window));
       g_free (error_msg);
       g_signal_emit (G_OBJECT (self), signals[DISCONNECTED], 0);
@@ -459,10 +461,12 @@ vinagre_tube_handler_factory_handle_cb (TpConnection *connection,
 
   if (error != NULL)
     {
-      error_msg = g_strdup_printf
-          (_("Impossible to get the contact name: %s"), error->message);
-      vinagre_utils_show_error (NULL, (const gchar *) error_msg,
-          GTK_WINDOW (priv->window));
+      /* Translators: this is an error message when we fail to get the name of an empathy/telepathy buddy. %s will be replaced by the actual error message. */
+      error_msg = g_strdup_printf (_("Impossible to get the contact name: %s"),
+                                   error->message);
+      vinagre_utils_show_error_dialog (NULL,
+                                (const gchar *) error_msg,
+                                GTK_WINDOW (priv->window));
       g_free (error_msg);
       g_signal_emit (G_OBJECT (self), signals[DISCONNECTED], 0);
       return;
@@ -497,7 +501,7 @@ vinagre_tube_handler_factory_handle_cb (TpConnection *connection,
               error_msg = g_strdup_printf
                   (_("Impossible to get the avatar: %s"),
                   error_failed->message);
-              vinagre_utils_show_error (NULL, (const gchar *) error_msg,
+              vinagre_utils_show_error_dialog (NULL, (const gchar *) error_msg,
                   GTK_WINDOW (priv->window));
               g_free (error_msg);
               image = gtk_image_new_from_icon_name ("stock_person",
